#!/usr/bin/env python3

import unittest
import amulet
import re

# Lots of prereqs on this charm so give it a large timeout
seconds_to_wait = 20000


class BundleTest(unittest.TestCase):
    """ Create a class for testing the charm in the unit test framework. """
    @classmethod
    def setUpClass(self):
        """
        Deployment test for IBM Spectrum Symphony Master.
        """

        self.d = amulet.Deployment(series='trusty')
        self.d.add('ibm-spectrum-symphony-storage')
        self.d.add('ibm-spectrum-symphony-master')
        self.d.relate('ibm-spectrum-symphony-storage:storage',
                      'ibm-spectrum-symphony-master:storage')
        self.d.setup(seconds_to_wait)
        self.d.sentry.wait(seconds_to_wait)

    def test_deploy_with_placeholder_resource(self):
        # The status message when using placeholder resources will include the
        # string "ibm_ss_installer resource".
        # If we see that, the test is successful.
        sentry_re = re.compile('ibm_ss_installer resource')
        self.d.sentry.wait_for_messages({"ibm-spectrum-symphony-storage":
                                        sentry_re})

    def test_unit_deployed(self):
        # verify unit
        self.assertTrue(self.d.deployed)
        unit_master_0 = self.d.sentry['ibm-spectrum-symphony-master'][0]
        state_master = unit_master_0.info['agent-state']
        print('Master Server is %s' % state_master)
        master_ip = unit_master_0.info['public-address']
        print('Master Server IP is %s' % master_ip)
        cmd1, code = unit_master_0.run(". /opt/ibm/spectrumsymphony/kernel"
                                       "/conf/profile.platform;"
                                       "egosh ego start all")
        if code != 0:
            message = 'ego command failed to run , may be symphony is down.'
            amulet.raise_status(amulet.FAIL, msg=message)
        print('The output of running ego command on master host is \n')
        print(str(cmd1))


if __name__ == '__main__':
    unittest.main()
